Built-in middleware implementations.
Structs
- Output
Formatter - Middleware that truncates tool output to a maximum character length.
- Permission
Checker - Middleware that checks tool call permissions against a
PermissionPolicy. - Schema
Validator - Middleware that validates tool call input against the tool’s JSON Schema.